@@ -19,11 +19,10 @@ Usage::
     list_human_loops_paginator: ListHumanLoopsPaginator = client.get_paginator("list_human_loops")
     ```
 """
-from mypy_boto3_sagemaker_a2i_runtime.client import (
-    AugmentedAIRuntimeClient as Client,
-    AugmentedAIRuntimeClient,
-)
+from mypy_boto3_sagemaker_a2i_runtime.client import AugmentedAIRuntimeClient
 from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
 
+Client = AugmentedAIRuntimeClient
+
 
 __all__ = ("AugmentedAIRuntimeClient", "Client", "ListHumanLoopsPaginator")
